Updated Space Invaders on the mbed. Improved upon Michael Son's "Mbed Space Invaders" at https://os.mbed.com/users/michaeljson/notebook/mbed-space-invaders/.

Dependencies:   mbed wave_player mbed-rtos 4DGL-uLCD-SE SparkfunAnalogJoystick SDFileSystem LSM9DS1_Library_cal_updated

Fork of Two-PlayerSpaceInvaders by William Minix

test

Revision:
15:33582e9acd16
Parent:
14:4e7608619043
Child:
16:e4e6515bdabb
--- a/main.cpp	Thu Apr 22 02:05:05 2021 +0000
+++ b/main.cpp	Thu Apr 22 14:34:34 2021 +0000
@@ -747,7 +747,7 @@
      //Thread thread3(mbedMaster); // uncommented if first player -- Brice
      Thread thread4(ledEffects); // thread added for LED lighting effects -- Brice
      secondMbed.baud(9600);
-     uLCD.baudrate(500000); // set to 500000 to increase smooth gameplay
+     uLCD.baudrate(3000000); // set to 3000000 to increase smooth gameplay
      
      // Initialization of Game Menu variables
     const int title_x_pos = 2; // initial x-pos of title